@@ -52,3 +52,14 @@ class ConfigGrep(Config):
         help_string="what regexp to look for?",
         default=None,
     )
+
+
+class ConfigPull(Config):
+    """
+    Parameters for the pull command
+    """
+
+    git_quiet = ParamCreator.create_bool(
+        help_string="add --quiet when running git?",
+        default=True,
+    )
